@@ -1,10 +1,10 @@
-from dnn_inference.BBoxTest import split_test, perm_test, Hperm_test
+from dnn_inference.sig_test import split_test, perm_test, Hperm_test
 import sys
 
 sys.path.append('..')
 
 __all__ = [
-    "BBoxTest",
+    "sig_test",
 	"split_test", 
 	"perm_test",
 	"Hperm_test"
